# Changelog

## Unreleased


## 1.7.0

* Plugin system introduced
* Pickup segmentation label

## 1.6.0

* Pickup seeds

## 1.5.0

* Keyboard shortcut for change label
* Keyboard shortcut for change brush

## 1.4.0
* Custom labels with selection from GUI added

## 1.3.0 

* Python 2 and python 3 compatibility